@@ -172,13 +172,16 @@ namespace Imendio.Blam {
 
             PrepareGUI();
 
-            Conf.AddNotify (Conf.GetFullKey(Preference.AUTO_REFRESH), new NotifyEventHandler (ConfNotifyHandler));
-
-            GLib.Idle.Add (new GLib.IdleHandler (IdleRefreshAll));
-
-            if(Conf.Get(Preference.REFRESH_AT_START, false) == true){
-                mCollection.RefreshAll();
+            if(Conf.Get(Preference.AUTO_REFRESH, false) == true){
+                StartStopAutoRefresh();
+                ShowNextUpdateTime();
+            } else {
+                if(Conf.Get(Preference.REFRESH_AT_START, false) == true){
+                    mCollection.RefreshAll();
+                }
             }
+
+            Conf.AddNotify (Conf.GetFullKey(Preference.AUTO_REFRESH), new NotifyEventHandler (ConfNotifyHandler));
         }
 
         private void PrepareGUI()
@@ -235,8 +238,8 @@ namespace Imendio.Blam {
 
             mainWindow.ShowAll ();
 
-            int ShowItemList = Conf.Get("ui/show_item_list", 1);
-            if(ShowItemList == 1){
+            bool ShowItemList = Conf.Get(Preference.SHOW_ITEM_LIST, true);
+            if(ShowItemList){
                 itemPaned.Child1.Visible = true;
             } else {
                 itemPaned.Child1.Visible = false;
@@ -256,10 +259,10 @@ namespace Imendio.Blam {
         {
             if(itemPaned.Child1.Visible){
                 itemPaned.Child1.Visible = false;
-                Conf.Set("ui/show_item_list", 0);
+                Conf.Set(Preference.SHOW_ITEM_LIST, false);
             } else {
                 itemPaned.Child1.Visible = true;
-                Conf.Set("ui/show_item_list", 1);
+                Conf.Set(Preference.SHOW_ITEM_LIST, true);
             }
         }
 
@@ -648,7 +651,10 @@ namespace Imendio.Blam {
 
         public void RefreshAllActivated(object obj, EventArgs args)
         {
-            mCollection.RefreshAll ();
+            /* First move the refresh back */
+            StartStopAutoRefresh();
+            /* And pretend a timeout occurred */
+            TimeoutRefreshAll();
         }
 
         private void DragDataReceivedCb(object o, DragDataReceivedArgs args)
@@ -723,26 +729,25 @@ namespace Imendio.Blam {
             }
         }
 
-        public bool IdleRefreshAll ()
+        private void ShowNextUpdateTime()
         {
-            TimeoutRefreshAll ();
+            uint contextId = statusbar.GetContextId("update-time");
 
-            StartStopAutoRefresh ();
-            return false;
+            statusbar.Pop(contextId);
+
+            int update_time = Conf.Get(Preference.AUTO_REFRESH_RATE, 15);
+            DateTime NextUpdate = DateTime.Now.AddMinutes(update_time);
+
+            /* This is the time (hour:minute) when the next update will be run */
+            String StatusString = String.Format(Catalog.GetString("Next update at {0}"), NextUpdate.ToShortTimeString());
+
+            statusbar.Push(contextId, StatusString);
         }
 
         private bool TimeoutRefreshAll ()
         {
-            int refreshRate;
-
-            if (Conf.Get (Preference.AUTO_REFRESH, false) == false) {
-                // User don't want auto refresh.
-                return false;
-            }
-
-            refreshRate = Conf.Get (Preference.AUTO_REFRESH_RATE, 15);
-
-            mCollection.RefreshAll (refreshRate);
+            ShowNextUpdateTime();
+            mCollection.RefreshAll();
 
             /* Continue until source is removed */
             return true;
@@ -763,7 +768,7 @@ namespace Imendio.Blam {
             }
 
             // Check if any feeds require refresh every ten seconds
-            mAutoRefreshId = GLib.Timeout.Add ((uint) (10 * 1000),
+            mAutoRefreshId = GLib.Timeout.Add ((uint) Conf.Get(Preference.AUTO_REFRESH_RATE, 15) * 60 * 1000,
                                                new GLib.TimeoutHandler (TimeoutRefreshAll));
         }
 
@@ -843,17 +848,23 @@ namespace Imendio.Blam {
 
         private void UpdateTotalNumberOfUnread ()
         {
-            int nrOfUnread;
+            int nrOfUnread, nrOfNew;
 
             nrOfUnread = mCollection.NrOfUnreadItems;
+            nrOfNew = mCollection.NrOfNewItems;
 
             channelsLabel.Markup = string.Format("<b>" +
                                                  channelsLabelText +
                                                  "</b>",
                                                  nrOfUnread);
 
-            trayIcon.Tooltip = string.Format (Catalog.GetPluralString ("{0} unread item", "{0} unread items", nrOfUnread),
+            /* Total number of unread items */
+            string str = string.Format (Catalog.GetPluralString ("{0} unread item", "{0} unread items", nrOfUnread),
                                              nrOfUnread);
+            str += " ";
+            /* Number of new (not-skipped-over) entries. Gets appended to previous string */
+            str += string.Format(Catalog.GetPluralString("({0} new)", "({0} new)", nrOfNew), nrOfNew);
+            trayIcon.Tooltip = str;
         }
 
 	public static void SetProcessName(string name)
