@@ -80,6 +80,20 @@ namespace Imendio.Blam {
 			}
 		}
 
+        public int NrOfNewItems {
+            get {
+                int new_items = 0;
+
+                foreach(Item item in mItems){
+                    if(item.Unread && !item.Old){
+                        ++new_items;
+                    }
+                }
+
+                return new_items;
+            }
+        }
+
 		ArrayList mItems;
 		[XmlElement ("Item", typeof (Item))]
 		public ArrayList Items {
